#!/bin/sh

if [ "x$1" = "x" ]; then
  SERVER="./server_simple"
else
  SERVER=$1
fi

if [ "x$1" = "x--help" ]; then
  echo "Use [SESSIONS=s] [RATE=r] $0 [server|server-ip]"
  exit 0
fi

if [ ! -f $SERVER ]; then
  #echo "$SERVER not found!"
  SERVERIP=$SERVER
else
  SERVERIP="localhost"
fi

if [ ! -f bigdata ]; then
  dd if=/dev/zero of=bigdata bs=1M count=5 > /dev/null 2>&1
fi

if [ "x$SESSIONS" = "x" ]; then
  SESSIONS=10
fi

if [ "x$RATE" = "x" ]; then
  RATE=10
fi

echo "#####################  TEST $SERVER ##########################"

if [ "x$SERVERIP" = "xlocalhost" ]; then
  $SERVER > /dev/null &
  PID=$!
fi

HTTPERF_OPTIONS="--client=0/1 --server=$SERVERIP --port=8000 --uri=/ --send-buffer=4096 --recv-buffer=16384 --rate $RATE"
GREP_ARG="Connection rate:\|CPU time\|Net I/O: \|test-duration"

######################################## C P U ##########################################
echo "Test CPU:"
httperf $HTTPERF_OPTIONS --wsesslog=$SESSIONS,0.000,session_cpu.txt 2> /dev/null | grep -e "$GREP_ARG"

######################################### I O ##########################################
echo "Test IO:"
httperf $HTTPERF_OPTIONS --wsesslog=$SESSIONS,0.000,session_io.txt 2> /dev/null | grep -e "$GREP_ARG"

###################################### M I X E D ########################################
echo "Test Mixed:"
httperf $HTTPERF_OPTIONS --wsesslog=$SESSIONS,0.000,session_mixed.txt 2> /dev/null | grep -e "$GREP_ARG"
# | grep -e "Connection rate:\|CPU time\|Net I/O: "

httperf --client=0/1 --server=$SERVERIP --port=8000 --uri=/ --send-buffer=4096 --recv-buffer=16384 --wsesslog=1,0.000,session_quit.txt > /dev/null 2>&1

if [ "x$SERVERIP" = "xlocalhost" ]; then
  kill $PID > /dev/null 2>&1
fi

exit 0
